@@ -1,7 +1,15 @@
 #from .. import Server
 from .route import Route, RouteParamType, RouteParameter
 
-def _handle_route(self, reqpath:str, request_headers):
+
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from .. import Server
+else:
+    Server = any
+
+def _handle_route(self:Server, reqpath:str, request_headers):
     path = tuple(int(ind) if ind.isdigit() else ind for ind in reqpath.split("?")[0].split("/"))
     route_key = Route("")
     for key in self.routes.keys():
